==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QLibraryInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qlibraryinfo.h>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qdatetime.h>
#include <QtCore/qversionnumber.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QLibraryInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QLibraryInfo")
    QLibraryInfo *_ptr = reinterpret_cast<QLibraryInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QLibraryInfo::build()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_build__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::build()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const char* __qt_return_value = QLibraryInfo::build();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::buildDate()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_buildDate__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::buildDate()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QDate __qt_return_value = QLibraryInfo::buildDate();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::isDebugBuild()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_isDebugBuild__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::isDebugBuild()")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QLibraryInfo::isDebugBuild();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::licensedProducts()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_licensedProducts__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::licensedProducts()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QString __qt_return_value = QLibraryInfo::licensedProducts();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::licensee()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_licensee__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::licensee()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QString __qt_return_value = QLibraryInfo::licensee();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::location(QLibraryInfo::LibraryLocation)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_location_1native_1QLibraryInfo_1LibraryLocation__I)
(JNIEnv *__jni_env,
 jclass,
 jint arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::location(QLibraryInfo::LibraryLocation)")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QLibraryInfo::LibraryLocation __qt_arg__1 = qtjambi_cast<QLibraryInfo::LibraryLocation>(__jni_env, arg__1);
        QString __qt_return_value = QLibraryInfo::location(QLibraryInfo::LibraryLocation(__qt_arg__1));
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::platformPluginArguments(QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_platformPluginArguments__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring platformName0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::platformPluginArguments(QString)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_platformName0 = qtjambi_cast<QString>(__jni_env, platformName0);
        QStringList __qt_return_value = QLibraryInfo::platformPluginArguments(__qt_platformName0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::version()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_version__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::version()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QVersionNumber __qt_return_value = QLibraryInfo::version();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QLibraryInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QLibraryInfo>("QLibraryInfo", "io/qt/core/QLibraryInfo");
// BEGIN: function table
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QLibraryInfo);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QLibraryInfo::LibraryLocation>("QLibraryInfo::LibraryLocation", "io/qt/core/QLibraryInfo$LibraryLocation");
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QLibraryInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/qlibraryinfo.h>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qversionnumber.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QLibraryInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QLibraryInfo")
    QLibraryInfo *_ptr = reinterpret_cast<QLibraryInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QLibraryInfo::build()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_build__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::build()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const char* __qt_return_value = QLibraryInfo::build();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::isDebugBuild()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_isDebugBuild__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::isDebugBuild()")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QLibraryInfo::isDebugBuild();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::isSharedBuild()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_isSharedBuild__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::isSharedBuild()")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QLibraryInfo::isSharedBuild();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::location(QLibraryInfo::LibraryLocation)
extern "C" QT_DEPRECATED Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_location_1native_1QLibraryInfo_1LibraryPath__I)
(JNIEnv *__jni_env,
 jclass,
 jint location0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::location(QLibraryInfo::LibraryLocation)")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QLibraryInfo::LibraryPath __qt_location0 = qtjambi_cast<QLibraryInfo::LibraryPath>(__jni_env, location0);
        QString __qt_return_value = QLibraryInfo::location(QLibraryInfo::LibraryPath(__qt_location0));
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::path(QLibraryInfo::LibraryPath)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_path_1native_1QLibraryInfo_1LibraryPath__I)
(JNIEnv *__jni_env,
 jclass,
 jint p0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::path(QLibraryInfo::LibraryPath)")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        QLibraryInfo::LibraryPath __qt_p0 = qtjambi_cast<QLibraryInfo::LibraryPath>(__jni_env, p0);
        QString __qt_return_value = QLibraryInfo::path(QLibraryInfo::LibraryPath(__qt_p0));
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::platformPluginArguments(QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_platformPluginArguments__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring platformName0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::platformPluginArguments(QString)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QString __qt_platformName0 = qtjambi_cast<QString>(__jni_env, platformName0);
        QStringList __qt_return_value = QLibraryInfo::platformPluginArguments(__qt_platformName0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLibraryInfo::version()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QLibraryInfo_version__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLibraryInfo::version()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QVersionNumber __qt_return_value = QLibraryInfo::version();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QLibraryInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QLibraryInfo>("QLibraryInfo", "io/qt/core/QLibraryInfo");
// BEGIN: function table
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QLibraryInfo);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QLibraryInfo::LibraryPath>("QLibraryInfo::LibraryPath", "io/qt/core/QLibraryInfo$LibraryPath");
// END: enums and flags
}
